@@ -60,14 +60,14 @@ def read(filename, norm=None, name="field"):
             listdata = list(struct.iter_unpack("@f", f[data_start:data_end]))
             try:
                 assert listdata[0] == 1234567.0
-            except:
+            except AssertionError:
                 raise AssertionError("Something has gone wrong "
                                      "with reading Binary Data")
         elif b"8" in header:
             listdata = list(struct.iter_unpack("@d", f[data_start:data_end]))
             try:
                 assert listdata[0][0] == 123456789012345.0
-            except:
+            except AssertionError:
                 raise AssertionError("Something has gone wrong "
                                      "with reading Binary Data")
 
